==> certmanager-model-v1beta1-5.10.2-sources.jar: io/fabric8/certmanager/api/model/v1beta1/CAIssuerFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1beta1;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class CAIssuerFluentImpl<A extends io.fabric8.certmanager.api.model.v1beta1.CAIssuerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.certmanager.api.model.v1beta1.CAIssuerFluent<A>{
  public CAIssuerFluentImpl() {
  }
  public CAIssuerFluentImpl(io.fabric8.certmanager.api.model.v1beta1.CAIssuer instance) {
    this.withCrlDistributionPoints(instance.getCrlDistributionPoints()); 
    this.withSecretName(instance.getSecretName()); 
  }
  private java.util.List<java.lang.String> crlDistributionPoints;
  private java.lang.String secretName;
  public A addToCrlDistributionPoints(java.lang.Integer index,java.lang.String item) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new java.util.ArrayList<java.lang.String>();}
    this.crlDistributionPoints.add(index, item);
    return (A)this;
  }
  public A setToCrlDistributionPoints(java.lang.Integer index,java.lang.String item) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new java.util.ArrayList<java.lang.String>();}
    this.crlDistributionPoints.set(index, item); return (A)this;
  }
  public A addToCrlDistributionPoints(java.lang.String... items) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.crlDistributionPoints.add(item);} return (A)this;
  }
  public A addAllToCrlDistributionPoints(java.util.Collection<java.lang.String> items) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.crlDistributionPoints.add(item);} return (A)this;
  }
  public A removeFromCrlDistributionPoints(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.crlDistributionPoints!= null){ this.crlDistributionPoints.remove(item);}} return (A)this;
  }
  public A removeAllFromCrlDistributionPoints(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.crlDistributionPoints!= null){ this.crlDistributionPoints.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getCrlDistributionPoints() {
    return this.crlDistributionPoints;
  }
  public java.lang.String getCrlDistributionPoint(java.lang.Integer index) {
    return this.crlDistributionPoints.get(index);
  }
  public java.lang.String getFirstCrlDistributionPoint() {
    return this.crlDistributionPoints.get(0);
  }
  public java.lang.String getLastCrlDistributionPoint() {
    return this.crlDistributionPoints.get(crlDistributionPoints.size() - 1);
  }
  public java.lang.String getMatchingCrlDistributionPoint(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: crlDistributionPoints) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingCrlDistributionPoint(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: crlDistributionPoints) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCrlDistributionPoints(java.util.List<java.lang.String> crlDistributionPoints) {
    if (crlDistributionPoints != null) {this.crlDistributionPoints = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : crlDistributionPoints){this.addToCrlDistributionPoints(item);}} else { this.crlDistributionPoints = null;} return (A) this;
  }
  public A withCrlDistributionPoints(java.lang.String... crlDistributionPoints) {
    if (this.crlDistributionPoints != null) {this.crlDistributionPoints.clear();}
    if (crlDistributionPoints != null) {for (java.lang.String item :crlDistributionPoints){ this.addToCrlDistributionPoints(item);}} return (A) this;
  }
  public java.lang.Boolean hasCrlDistributionPoints() {
    return crlDistributionPoints != null && !crlDistributionPoints.isEmpty();
  }
  public A addNewCrlDistributionPoint(java.lang.String arg0) {
    return (A)addToCrlDistributionPoints(new String(arg0));
  }
  public java.lang.String getSecretName() {
    return this.secretName;
  }
  public A withSecretName(java.lang.String secretName) {
    this.secretName=secretName; return (A) this;
  }
  public java.lang.Boolean hasSecretName() {
    return this.secretName != null;
  }
  
  /**
   * Method is deprecated. use withSecretName instead.
   */
  @java.lang.Deprecated
  public A withNewSecretName(java.lang.String arg0) {
    return (A)withSecretName(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CAIssuerFluentImpl that = (CAIssuerFluentImpl) o;
    if (crlDistributionPoints != null ? !crlDistributionPoints.equals(that.crlDistributionPoints) :that.crlDistributionPoints != null) return false;
    if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(crlDistributionPoints,  secretName,  super.hashCode());
  }
  
}

==> certmanager-model-v1beta1-5.12.3-sources.jar: io/fabric8/certmanager/api/model/v1beta1/CAIssuerFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1beta1;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class CAIssuerFluentImpl<A extends io.fabric8.certmanager.api.model.v1beta1.CAIssuerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.certmanager.api.model.v1beta1.CAIssuerFluent<A>{
  public CAIssuerFluentImpl() {
  }
  public CAIssuerFluentImpl(io.fabric8.certmanager.api.model.v1beta1.CAIssuer instance) {
    this.withCrlDistributionPoints(instance.getCrlDistributionPoints()); 
    this.withSecretName(instance.getSecretName()); 
  }
  private java.util.List<java.lang.String> crlDistributionPoints;
  private java.lang.String secretName;
  public A addToCrlDistributionPoints(java.lang.Integer index,java.lang.String item) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new java.util.ArrayList<java.lang.String>();}
    this.crlDistributionPoints.add(index, item);
    return (A)this;
  }
  public A setToCrlDistributionPoints(java.lang.Integer index,java.lang.String item) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new java.util.ArrayList<java.lang.String>();}
    this.crlDistributionPoints.set(index, item); return (A)this;
  }
  public A addToCrlDistributionPoints(java.lang.String... items) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.crlDistributionPoints.add(item);} return (A)this;
  }
  public A addAllToCrlDistributionPoints(java.util.Collection<java.lang.String> items) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.crlDistributionPoints.add(item);} return (A)this;
  }
  public A removeFromCrlDistributionPoints(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.crlDistributionPoints!= null){ this.crlDistributionPoints.remove(item);}} return (A)this;
  }
  public A removeAllFromCrlDistributionPoints(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.crlDistributionPoints!= null){ this.crlDistributionPoints.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getCrlDistributionPoints() {
    return this.crlDistributionPoints;
  }
  public java.lang.String getCrlDistributionPoint(java.lang.Integer index) {
    return this.crlDistributionPoints.get(index);
  }
  public java.lang.String getFirstCrlDistributionPoint() {
    return this.crlDistributionPoints.get(0);
  }
  public java.lang.String getLastCrlDistributionPoint() {
    return this.crlDistributionPoints.get(crlDistributionPoints.size() - 1);
  }
  public java.lang.String getMatchingCrlDistributionPoint(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: crlDistributionPoints) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingCrlDistributionPoint(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: crlDistributionPoints) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCrlDistributionPoints(java.util.List<java.lang.String> crlDistributionPoints) {
    if (crlDistributionPoints != null) {this.crlDistributionPoints = new java.util.ArrayList(); for (java.lang.String item : crlDistributionPoints){this.addToCrlDistributionPoints(item);}} else { this.crlDistributionPoints = null;} return (A) this;
  }
  public A withCrlDistributionPoints(java.lang.String... crlDistributionPoints) {
    if (this.crlDistributionPoints != null) {this.crlDistributionPoints.clear();}
    if (crlDistributionPoints != null) {for (java.lang.String item :crlDistributionPoints){ this.addToCrlDistributionPoints(item);}} return (A) this;
  }
  public java.lang.Boolean hasCrlDistributionPoints() {
    return crlDistributionPoints != null && !crlDistributionPoints.isEmpty();
  }
  public A addNewCrlDistributionPoint(java.lang.String arg0) {
    return (A)addToCrlDistributionPoints(new String(arg0));
  }
  public java.lang.String getSecretName() {
    return this.secretName;
  }
  public A withSecretName(java.lang.String secretName) {
    this.secretName=secretName; return (A) this;
  }
  public java.lang.Boolean hasSecretName() {
    return this.secretName != null;
  }
  
  /**
   * Method is deprecated. use withSecretName instead.
   */
  @java.lang.Deprecated
  public A withNewSecretName(java.lang.String arg0) {
    return (A)withSecretName(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CAIssuerFluentImpl that = (CAIssuerFluentImpl) o;
    if (crlDistributionPoints != null ? !crlDistributionPoints.equals(that.crlDistributionPoints) :that.crlDistributionPoints != null) return false;
    if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(crlDistributionPoints,  secretName,  super.hashCode());
  }
  
}
